@@ -5,8 +5,12 @@ TMPDIST="$(mktemp -d)"
 USERBASE="$(mktemp -d)"
 trap "rm -rf '$TMPDIST' '$USERBASE'" EXIT
 
-for pybin in /opt/python/cp{36,37,38,39,310}-cp*/bin; do
-    "${pybin}/pip" wheel --no-cache-dir -w "$TMPDIST" ".[testing]"
+pybins=(/opt/python/cp{37,38,39,310,311}-cp*/bin)
+
+SRCDIST="$(ls -vr dist/blurhash-python-*.tar.gz | head -n1)"
+
+for pybin in ${pybins[@]}; do
+    "${pybin}/pip" wheel --no-cache-dir -w "$TMPDIST" "$SRCDIST[testing]"
 done
 
 for whl in "$TMPDIST"/blurhash_python*.whl; do
@@ -16,7 +20,7 @@ done
 
 ORIGPATH="$PATH"
 
-for pybin in /opt/python/cp{36,37,38,39,310}-cp*/bin; do
+for pybin in ${pybins[@]}; do
     userbindir="$USERBASE/${pybin#/opt/python/}"
     export PYTHONUSERBASE="${userbindir%/bin}"
     export PATH="$ORIGPATH:$userbindir"
