@@ -2,6 +2,7 @@ from __future__ import absolute_import
 
 import pytest
 
+from PIL import Image
 from blurhash import encode
 
 
@@ -12,6 +13,13 @@ def test_encode_file():
     assert result == 'LlMF%n00%#MwS|WCWEM{R*bbWBbH'
 
 
+def test_encode_pil_image():
+    with Image.open('tests/pic2.png') as image:
+        result = encode(image, 4, 3)
+
+    assert result == 'LlMF%n00%#MwS|WCWEM{R*bbWBbH'
+
+
 def test_encode_with_filename():
     result = encode('tests/pic2.png', 4, 3)
     assert result == 'LlMF%n00%#MwS|WCWEM{R*bbWBbH'
